@@ -113,5 +113,5 @@ def get_new_proxy_2(
     return proxy
 
 
-data = get_new_proxy_2()
-print(data)
\ No newline at end of file
+# data = get_new_proxy_2()
+# print(data)
\ No newline at end of file
